# fulfill

[![ci](https://github.com/pawamoy/fulfill/workflows/ci/badge.svg)](https://github.com/pawamoy/fulfill/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs-708FCC.svg?style=flat)](https://pawamoy.github.io/fulfill/)
[![pypi version](https://img.shields.io/pypi/v/fulfill.svg)](https://pypi.org/project/fulfill/)
[![gitpod](https://img.shields.io/badge/gitpod-workspace-708FCC.svg?style=flat)](https://gitpod.io/#https://github.com/pawamoy/fulfill)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://app.gitter.im/#/room/#fulfill:gitter.im)

Manage your project. Fulfill your duties.

## Installation

With `pip`:

```bash
pip install fulfill
```

With [`pipx`](https://github.com/pipxproject/pipx):

```bash
python3.8 -m pip install --user pipx
pipx install fulfill
```
